/*
 * fsarchiver: Filesystem Archiver
 *
 * Copyright (C) 2008-2009 Francois Dupoux.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License v2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * Homepage: http://www.fsarchiver.org
 */

#ifndef __ERROR_H__
#define __ERROR_H__

int myprintf(int showerrno, char *format, ...);
int logprintf(char *format, ...);

// ----------------------------------- error codes --------------------------------------------------
enum	{ERR_FAIL=-1, ERR_SUCCESS=0, ERR_FATAL=1, ERR_MINOR=2};

// used to print error messages (sysprintf when after a syscall, errprintf for normal function calls)
#define sysprintf(fmt, args...)					\
{ 	fprintf(stderr, "%s#%d: ", __FILE__ , __LINE__);	\
	myprintf(1, fmt, ## args);				\
	logprintf("%s#%d: ", __FILE__ , __LINE__);		\
	logprintf(fmt, ## args); 				\
}

#define errprintf(fmt, args...)					\
{	fprintf(stderr, "%s#%d: ", __FILE__ , __LINE__);	\
	myprintf(0, fmt, ## args);				\
	logprintf("%s#%d: ", __FILE__ , __LINE__);		\
	logprintf(fmt, ## args);				\
}

// normal messages: level=0 will always be printed, level=1 will be printed when options.verboselevel==1, ...
#define msgprintf(level, fmt, args...)				\
{	if (g_options.verboselevel>=level)			\
	{	myprintf(0, fmt, ## args);			\
	}							\
}

// messages to be printed to /var/log/fsarchiver.log when troubleshooting
#define dbgprintf(level, fmt, args...)				\
{	if (g_options.debuglevel>=level)			\
	{	logprintf("%s#%d: ", __FILE__ , __LINE__);	\
		logprintf(fmt, ## args);			\
	} 							\
}

// multithreading debugging
#define mtprintf(fmt, args...)					\
{	fprintf(stderr, "[%.2d]-%s#%d: ", (int)pthread_self()%100, __FILE__ , __LINE__);	\
	myprintf(0, fmt, ## args);				\
}

#endif // __ERROR_H__
